==> a2p2-0.1.4.tar.gz: a2p2-0.1.4/setup.py <==
from setuptools import setup, find_packages
from sys import platform

with open('README.rst') as README:
    long_description = README.read()
    description = long_description[:long_description.index('Description')].split("*")[1].strip()
    long_description = long_description[long_description.index('Description'):]

version = {}
with open("a2p2/version.py") as fp:
    exec(fp.read(), version)



setup(
      name='a2p2',
      version=version['__version__'],
      description=description,
      long_description=long_description,
      #      install_requires=['astropy', 'p2api','pygtk'],
      # PyGtk is not working on some linux
      # anaconda also fails 
      # prefere the use of your default python packages on your linux
      # what is the solution for mac ?
      # we continue moving tk as first gui backend
      # install_requires=['astropy', 'p2api', 'python-tk'] + (['pygtk'] if platform.startswith("win") else []),
      install_requires=['astropy>=2', 'p2api'] + (['pygtk'] if platform.startswith("win") else []),
      url='http://www.jmmc.fr/a2p2',
      author='JMMC Tech Group',
      author_email='jmmc-tech-group@jmmc.fr',
      classifiers=[
      'Development Status :: 4 - Beta',
      'Intended Audience :: Developers',
      'Programming Language :: Python :: 2',
      'Programming Language :: Python :: 2.7',
      'Programming Language :: Python :: 3',
      'Programming Language :: Python :: 3.6',
      ],
      license='OSI Approved :: GNU General Public License v3 (GPLv3)',
      packages=find_packages(),
      include_package_data=True,
      scripts=['scripts/a2p2'],
      keywords='observation preparation tool optical-interferometry p2 samp'
      )

==> a2p2-0.2.0.tar.gz: a2p2-0.2.0/setup.py <==
from setuptools import setup, find_packages
from sys import platform

with open('README.rst') as README:
    long_description = README.read()
    description = long_description[
        :long_description.index('Description')].split("*")[1].strip()
    long_description = long_description[long_description.index('Description'):]

version = {}
with open("a2p2/version.py") as fp:
    exec(fp.read(), version)


setup(
    name='a2p2',
      version=version['__version__'],
      description=description,
      long_description=long_description,
      #      install_requires=['astropy', 'p2api','pygtk'],
      # PyGtk is not working on some linux
      # anaconda also fails
      # prefere the use of your default python packages on your linux
      # what is the solution for mac ?
      # we continue moving tk as first gui backend
      # install_requires=['astropy', 'p2api', 'python-tk'] + (['pygtk'] if
      # platform.startswith("win") else []),
      install_requires=['astropy>=2', 'p2api'],
      url='http://www.jmmc.fr/a2p2',
      author='JMMC Tech Group',
      author_email='jmmc-tech-group@jmmc.fr',
      classifiers=[
          'Development Status :: 4 - Beta',
          'Intended Audience :: Developers',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.6',
      ],
      license='OSI Approved :: GNU General Public License v3 (GPLv3)',
      packages=find_packages(),
      include_package_data=True,
      scripts=['scripts/a2p2'],
      keywords='observation preparation tool optical-interferometry p2 samp'
)
